@@ -295,7 +295,9 @@ class WorkerDataAssertFact(SwaggerView):
 
         # here also upload data and create rdf record
 
-        dag_bucket = odakb.datalake.form_bucket_name(dag)
+        dag_bucket = "odahub-" + odakb.datalake.form_bucket_name(dag)
+        
+        logger.info("storing object %s in dag-motivated bucket: %s", dag[-1], dag_bucket)
 
         bucket = odakb.datalake.store(
                     dict(dag=dag, data=data),
@@ -303,10 +305,11 @@ class WorkerDataAssertFact(SwaggerView):
                 )
 
         assert bucket == dag_bucket
-        
+
+        logger.info("succesfully returning!")
 
         return jsonify(
-                { 'bucket': bucket }
+                    { 'bucket': bucket }
                )
 
 
@@ -354,8 +357,8 @@ class WorkerDataConsultFact(SwaggerView):
 
         logger.info("worker %s consulting fact of dag %s", worker_id, len(dag))
 
-        dag_bucket = odakb.datalake.form_bucket_name(dag)
-        logger.info("dag bucket %s", dag_bucket)
+        dag_bucket = "odahub-" + odakb.datalake.form_bucket_name(dag)
+        logger.info("dag %s bucket %s", dag[-1], dag_bucket)
 
         try:
             meta, payload  = odakb.datalake.restore(dag_bucket, return_metadata=True)
