@@ -28,13 +28,13 @@ except ImportError:
 
 from typing import NewType, Dict, Union, List
 
-import dqueue.typing as types
+import dqueue.dqtyping as dqtyping
 from dqueue.entry import decode_entry_data
 
 import pymysql
 import peewee # type: ignore
-from playhouse.db_url import connect # type: ignore
-from playhouse.shortcuts import model_to_dict, dict_to_model # type: ignore
+
+from dqueue.database import EventLog, TaskEntry, db, model_to_dict
 
 sleep_multiplier = 1
 n_failed_retries = int(os.environ.get('DQUEUE_FAILED_N_RETRY','20'))
@@ -72,61 +72,6 @@ class CurrentTaskUnfinished(Exception):
 class TaskStolen(Exception):
     pass
 
-
-def connect_db():
-    return connect(os.environ.get("DQUEUE_DATABASE_URL","mysql+pool://root@localhost/dqueue?max_connections=42&stale_timeout=8001.2"))
-
-try:
-    db=connect_db()
-    logger.info(f"successfully connected to db: {db}")
-except Exception as e:
-    logger.warning("unable to connect to DB: %s", repr(e))
-
-    
-
-class TaskEntry(peewee.Model):
-    database = None
-
-    queue = peewee.CharField(default="default")
-
-    key = peewee.CharField(primary_key=True)
-    state = peewee.CharField()
-    worker_id = peewee.CharField()
-
-    task_dict_string = peewee.TextField()
-
-    created = peewee.DateTimeField()
-    modified = peewee.DateTimeField()
-
-    class Meta:
-        database = db
-
-
-class EventLog(peewee.Model):
-    queue = peewee.CharField(default="default")
-
-    task_key = peewee.CharField(default="unset")
-    task_state = peewee.CharField(default="unset")
-
-    worker_id = peewee.CharField()
-    worker_state = peewee.CharField(default="unset")
-
-    timestamp = peewee.DateTimeField(default=datetime.datetime.now)
-    message = peewee.CharField(default="unset")
-    
-    spent_s = peewee.FloatField(default=0)
-
-    class Meta:
-        database = db
-
-try:
-    db.create_tables([TaskEntry, EventLog])
-    has_mysql = True
-except peewee.OperationalError:
-    has_mysql = False
-except Exception:
-    has_mysql = False
-
 class Task:
     reference_task = False
 
@@ -307,7 +252,7 @@ class Queue:
         self.current_task_status=None
         self.logger = logging.getLogger(repr(self))
 
-    def find_task_instances(self, task: Task, klist: Union[list, None]=None) -> List[types.TaskEntry]:
+    def find_task_instances(self, task: Task, klist: Union[list, None]=None) -> List[dqtyping.TaskEntry]:
         ""
         log("find_task_instances for",task.key,"in",self.queue)
 
@@ -357,7 +302,7 @@ class Queue:
         log("task still locked", task.key)
         return dict(state="locked",key=task.key)
     
-    def task_by_key(self, key: str, decode: bool=False) -> Union[types.TaskDict, None]:
+    def task_by_key(self, key: str, decode: bool=False) -> Union[dqtyping.TaskDict, None]:
         ""
 
         r=TaskEntry.select().where(
@@ -379,7 +324,7 @@ class Queue:
 
 
     
-    def put(self, task_data: types.TaskData, submission_data=None, depends_on=None) -> Union[types.TaskEntry, None]:
+    def put(self, task_data: dqtyping.TaskData, submission_data=None, depends_on=None) -> Union[dqtyping.TaskEntry, None]:
         logger.info("putting in queue task_data %s", task_data)
 
         assert depends_on is None or type(depends_on) in [list, tuple] # runtime typing!
@@ -389,7 +334,7 @@ class Queue:
 
         task=Task(task_data, submission_data=submission_data, depends_on=depends_on)
 
-        instances_for_key = None # type: Union[List[types.TaskEntry], None]
+        instances_for_key = None # type: Union[List[dqtyping.TaskEntry], None]
 
         ntry_race=10
         retry_sleep_race=2
@@ -412,7 +357,7 @@ class Queue:
         if instances_for_key is None or len(instances_for_key)>1:
             raise Exception("probably race condition, multiple task instances:",instances_for_key)
 
-        instance_for_key = None # type: Union[types.TaskEntry, None]
+        instance_for_key = None # type: Union[dqtyping.TaskEntry, None]
         if len(instances_for_key) == 1:
             instance_for_key = instances_for_key[0]
 
@@ -545,14 +490,15 @@ class Queue:
             f.append(EventLog.timestamp < t0)
             logger.warning('clearing older events: %s', f)
 
-        if only_kind == "task":
-            f.append(EventLog.worker_state == "unset")
-            logger.warning('clearing task events: %s', f)
-        elif only_kind == "worker":
-            f.append(EventLog.worker_state != "unset")
-            logger.warning('clearing worker events: %s', f)
-        else:
-            raise RuntimeError(f"unknown kind {only_kind}; expecting 'task' or 'worker'")
+        if only_kind is not None:
+            if only_kind == "task":
+                f.append(EventLog.worker_state == "unset")
+                logger.warning('clearing task events: %s', f)
+            elif only_kind == "worker":
+                f.append(EventLog.worker_state != "unset")
+                logger.warning('clearing worker events: %s', f)
+            else:
+                raise RuntimeError(f"unknown kind {only_kind}; expecting 'task' or 'worker'")
 
         F = reduce(lambda x,y: x&y, f)
 
@@ -597,6 +543,11 @@ class Queue:
             time.sleep(retry_delay + (30 - n_tries_left))
 
             try:
+                try:
+                    db.close()
+                except Exception as e:
+                    self.log_task(f"db close before reconnect failed", state="db_reconnected")
+
                 db.connect()
                 self.log_task(f"managed to reconnect! {repr(e)}", state="db_reconnected")
             except peewee.OperationalError as e:
@@ -724,7 +675,7 @@ class Queue:
 
 
 
-    def task_locked(self, depends_on: List[types.TaskDict]):
+    def task_locked(self, depends_on: List[dqtyping.TaskDict]):
         ""
         if not isinstance(depends_on, list):
             raise Exception(f"depends_on has unknown type {depends_on.__class__}, expected list")
