@@ -13,79 +13,22 @@ from urllib.parse import urlparse# type: ignore
 
 from dqueue.core import Queue, Empty, Task, CurrentTaskUnfinished
 import dqueue.core as core
-import dqueue.typing as types
+from dqueue import dqtyping
 from typing import Union
 from dqueue import tools
 
-from retrying import retry
+from retrying import retry # type: ignore
 
 from bravado.client import SwaggerClient, RequestsClient
 
+from dqueue.client import APIClient
+from dqueue.data import DataFacts
 
-
-class QueueProxy(Queue):
-    leader = None
-    queue = None
-
-    _token = None
-
-    @property
-    def token(self) -> str:
-        if self._token is None:
-            for n, m in [
-                    ("env", lambda: os.environ.get('DDA_TOKEN').strip()), # type: ignore
-                    ("home-dotfile", lambda: open(os.environ.get('HOME')+"/.dda-token").read().decode().strip()), # type: ignore
-                    ("cwd-dotfile", lambda: open(".dda-token").read().decode().strip()), # type: ignore
-                    ]:
-                try:
-                    print("trying", n)
-                    self._token = m()
-                    print("method succeeded!")
-                    break
-                except Exception as e:
-                    print(f"method {n} failed: {e}")
-
-            if self._token is None:
-                print(f"all methods to get token failed using default empty")
-                self._token = ""
-
-        return self._token
-
-    def __repr__(self):
-        return f"[ {self.__class__.__name__}: {self.leader}@{self.queue} : {self.current_task} ]"
-
-    def __init__(self, queue_uri="http://localhost:5000@default"):
-        super().__init__()
-
-        r = re.search("(https?://.*?)@(.*)", queue_uri)
-        if not r:
-            raise Exception("uri does not match queue")
-
-        self.leader = r.groups()[0]
-        self.queue = r.groups()[1]
-
-        self.logger = logging.getLogger(repr(self))
+class QueueProxy(DataFacts, Queue):
 
     def list_queues(self, pattern):
         print(self.client.queues.list().response().result)
-        return [QueueProxy(self.leader+"@"+q) for q in self.client.queues.list().response().result]
-
-    @property
-    def client(self):
-        if getattr(self, '_client', None) is None:
-            http_client = RequestsClient()
-
-            http_client.set_api_key(
-                             urlparse(self.leader).netloc, "Bearer "+ self.token,
-                             param_name='Authorization', param_in='header'
-                            )
-
-            self._client = SwaggerClient.from_url(
-                        self.leader.strip("/")+"/apispec_1.json",
-                        config={'use_models': False},
-                        http_client=http_client,
-                    )
-        return self._client
+        return [ QueueProxy(self.leader+"@"+q) for q in self.client.queues.list().response().result ]
 
     def find_task_instances(self,task,klist=None):
         raise NotImplementedError
@@ -97,7 +40,7 @@ class QueueProxy(Queue):
     def task_info(self, key):
         return self.client.task.task_info(task_key=key).response().result
 
-    def task_by_key(self, key: str, decode: bool=False) -> types.TaskDict:
+    def task_by_key(self, key: str, decode: bool=False) -> dqtyping.TaskDict:
         r = self.client.task.task_info(task_key=key).response().result
 
         if decode:
@@ -107,7 +50,7 @@ class QueueProxy(Queue):
 
     def clear_event_log(self, only_older_than_days: Union[float,None]=None, only_kind: Union[str,None]=None):
         return self.client.log.clear(only_older_than_days=only_older_than_days,
-                                     only_kind=only_kind).response().result['N']
+                                     only_kind=only_kind).response().result
     
     def view_log(self, task_key=None, since=0):
         if task_key is None:
@@ -115,7 +58,7 @@ class QueueProxy(Queue):
 
         return self.client.log.view(task_key=task_key,
                                          since=since,
-                                         token=self.token).response().result
+                                         ).response().result
     
     def log_queue(self, message, spent_s=0):
         self.logger.info("log queue %s", message)
@@ -123,7 +66,7 @@ class QueueProxy(Queue):
         return self.client.worker.logQueue(message=message,
                                    spent_s=spent_s,
                                    worker_id=self.worker_id,
-                                   token=self.token).response().result
+                                   ).response().result
     
     def log_task(self, message, task=None, state="unset", task_key=None):
         self.logger.info("log_task %s", message)
@@ -140,16 +83,17 @@ class QueueProxy(Queue):
                                state=state, 
                                queue=self.queue, 
                                worker_id=self.worker_id,
-                               token=self.token).response().result
+                               ).response().result
 
         def retry_on_exception(exception):
-            self.logger.error("%s: error in client log_task: %s; trying to send %s %s %s %s %s %s", self, exception,
+            self.logger.error("%s: error in client log_task: %s; trying to send %s %s %s %s %s",
+                        self, 
+                        exception,
                         message,
                         task_key,
                         state,
                         self.queue,
                         self.worker_id,
-                        self.token,
                     )
             return True
 
@@ -168,7 +112,6 @@ class QueueProxy(Queue):
         return self.client.worker.questionTask(
                     worker_id=self.worker_id,
                     task_data=task_data,
-                    token=self.token,
                     queue=self.queue,
                 ).response().result
 
@@ -179,7 +122,7 @@ class QueueProxy(Queue):
 
         print(dir(self.client.worker))
 
-        r = self.client.worker.getOffer(worker_id=self.worker_id, queue=self.queue, token=self.token).response()
+        r = self.client.worker.getOffer(worker_id=self.worker_id, queue=self.queue).response()
 
         if r.result is None:
             raise Empty()
@@ -197,7 +140,6 @@ class QueueProxy(Queue):
 
         r = self.client.worker.answer(worker_id=self.worker_id, 
                                       queue=self.queue, 
-                                      token=self.token,
                                       task_dict=self.current_task.as_dict,
                                       ).response().result
 
@@ -244,5 +186,6 @@ class QueueProxy(Queue):
         return self.client.tasks.resubmit(scope=scope, selector=selector)
 
     def try_all_locked(self):
-        return self.client.tasks.try_all_locked(worker_id=self.worker_id, token=self.token, queue=self.queue).response().result
+        return self.client.tasks.try_all_locked(worker_id=self.worker_id, queue=self.queue).response().result
+
 
